@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2009-2010 LabKey Corporation
+#  Copyright (c) 2009-2012 LabKey Corporation
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -30,8 +30,8 @@ if(substr(baseUrl, nchar(baseUrl), nchar(baseUrl))!="/"){baseUrl <- paste(baseUr
 if(substr(folderPath, nchar(folderPath), nchar(folderPath))!="/"){folderPath <- paste(folderPath,"/",sep="")}
 if(substr(folderPath, 1, 1)!="/"){folderPath <- paste("/",folderPath,sep="")}
 
-## URL encode folder path, JSON encode post body
-if(length(grep("%",folderPath))<1) {folderPath <- URLencode(folderPath)}
+## URL encode folder path, JSON encode post body (if not already encoded)
+if(folderPath==URLdecode(folderPath)) {folderPath <- URLencode(folderPath)}
 nrows <- nrow(toUpdate)
 ncols <- ncol(toUpdate)
 p1 <- toJSON(list(schemaName=schemaName, queryName=queryName, apiVersion=8.3))
