@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2008-2011 Fred Hutchinson Cancer Research Center
+#  Copyright (c) 2008-2012 Fred Hutchinson Cancer Research Center
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -36,6 +36,8 @@
  								"NOT_EQUAL_OR_MISSING"="neqornull",
  								"DATE_EQUAL"="dateeq",
  								"DATE_NOT_EQUAL"="dateneq",
+ 								"DATE_GREATER_THAN_OR_EQUAL"="dategte",
+ 								"DATE_LESS_THAN_OR_EQUAL"="datelte",
  								"IS_MISSING"="isblank",
  								"MISSING"="isblank",
  								"IS_NOT_MISSING"="isnonblank",
@@ -45,16 +47,21 @@
  								"GREATER_THAN_OR_EQUAL"="gte",
  								"LESS_THAN"="lt",
  								"LESS_THAN_OR_EQUAL_TO"="lte",
+ 								"LESS_THAN_OR_EQUAL"="lte",
  								"CONTAINS"="contains",
  								"DOES_NOT_CONTAIN"="doesnotcontain",
  								"STARTS_WITH"="startswith",
  								"DOES_NOT_START_WITH"="doesnotstartwith",
  								"EQUALS_ONE_OF"="in",
+ 								"IN"="in",
 								"MV_INDICATOR"="hasmvvalue",
-								"NO_MV_INDICATOR"="nomvvalue",
 								"QC_VALUE"="hasmvvalue",
-								"NOT_QC_VALUE"="nomvvalue")
-								# last two  for backward compatibility of renamed feature
+								"NO_MV_INDICATOR"="nomvvalue",
+								"NOT_QC_VALUE"="nomvvalue",
+								"EQUALS_NONE_OF"="notin",
+								"NOT_IN"="notin",
+								"CONTAINS_ONE_OF"="containsoneof",
+								"CONTAINS_NONE_OF"="containsnoneof")
 								
  				if(is.null(fop)==TRUE) stop ("Invalid operator name.")
  				# url encode column name and value
